package com.ruoyi.system.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.SysTreeDictMapper;
import com.ruoyi.system.domain.SysTreeDict;
import com.ruoyi.system.service.ISysTreeDictService;

/**
 * 树形字典Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-02-03
 */
@Service
public class SysTreeDictServiceImpl implements ISysTreeDictService 
{
    @Autowired
    private SysTreeDictMapper sysTreeDictMapper;

    /**
     * 查询树形字典
     * 
     * @param id 树形字典主键
     * @return 树形字典
     */
    @Override
    public SysTreeDict selectSysTreeDictById(Long id)
    {
        return sysTreeDictMapper.selectSysTreeDictById(id);
    }

    /**
     * 查询树形字典列表
     * 
     * @param sysTreeDict 树形字典
     * @return 树形字典
     */
    @Override
    public List<SysTreeDict> selectSysTreeDictList(SysTreeDict sysTreeDict)
    {
        return sysTreeDictMapper.selectSysTreeDictList(sysTreeDict);
    }

    /**
     * 新增树形字典
     * 
     * @param sysTreeDict 树形字典
     * @return 结果
     */
    @Override
    public int insertSysTreeDict(SysTreeDict sysTreeDict)
    {
        sysTreeDict.setCreateTime(DateUtils.getNowDate());
        return sysTreeDictMapper.insertSysTreeDict(sysTreeDict);
    }

    /**
     * 修改树形字典
     * 
     * @param sysTreeDict 树形字典
     * @return 结果
     */
    @Override
    public int updateSysTreeDict(SysTreeDict sysTreeDict)
    {
        sysTreeDict.setUpdateTime(DateUtils.getNowDate());
        return sysTreeDictMapper.updateSysTreeDict(sysTreeDict);
    }

    /**
     * 批量删除树形字典
     * 
     * @param ids 需要删除的树形字典主键
     * @return 结果
     */
    @Override
    public int deleteSysTreeDictByIds(Long[] ids)
    {
        return sysTreeDictMapper.deleteSysTreeDictByIds(ids);
    }

    /**
     * 删除树形字典信息
     * 
     * @param id 树形字典主键
     * @return 结果
     */
    @Override
    public int deleteSysTreeDictById(Long id)
    {
        return sysTreeDictMapper.deleteSysTreeDictById(id);
    }
}
